// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
import { NoOpTracer } from "./tracers/noop/noOpTracer";
import { getCache } from "./utils/cache";
/**
 * Sets the global tracer, enabling tracing for the Azure SDK.
 * @param tracer An OpenTelemetry Tracer instance.
 */
export function setTracer(tracer) {
    var cache = getCache();
    cache.tracer = tracer;
}
/**
 * Retrieves the active tracer, or returns a
 * no-op implementation if one is not set.
 */
export function getTracer() {
    var cache = getCache();
    if (!cache.tracer) {
        cache.tracer = new NoOpTracer();
    }
    return cache.tracer;
}
//# sourceMappingURL=tracerProxy.js.map