// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
import { getGlobalObject } from "./global";
var GLOBAL_TRACER_VERSION = 1;
var GLOBAL_TRACER_SYMBOL = Symbol.for("@azure/core-tracing.tracerCache");
var cache;
function loadTracerCache() {
    var globalObj = getGlobalObject();
    var existingCache = globalObj[GLOBAL_TRACER_SYMBOL];
    if (existingCache) {
        if (existingCache.version !== GLOBAL_TRACER_VERSION) {
            throw new Error("Two incompatible versions of @azure/core-tracing have been loaded.\n         This library is " + GLOBAL_TRACER_VERSION + ", existing is " + existingCache.version + ".");
        }
        cache = existingCache;
    }
    else {
        cache = {
            tracer: undefined,
            version: GLOBAL_TRACER_VERSION
        };
        globalObj[GLOBAL_TRACER_SYMBOL] = cache;
    }
}
export function getCache() {
    if (!cache) {
        loadTracerCache();
    }
    return cache;
}
//# sourceMappingURL=cache.js.map