// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { __assign } from "tslib";
import { getTracer, SpanKind } from "@azure/core-tracing";
/**
 * Creates a span using the global tracer.
 * @param name The name of the operation being performed.
 * @param tracingOptions The options for the underlying http request.
 */
export function createSpan(operationName, tracingOptions) {
    if (tracingOptions === void 0) { tracingOptions = {}; }
    var tracer = getTracer();
    var spanOptions = __assign(__assign({}, tracingOptions.spanOptions), { kind: SpanKind.CLIENT });
    var span = tracer.startSpan("Azure.Storage.Blob." + operationName, spanOptions);
    span.setAttribute("component", "storage");
    var newOptions = tracingOptions.spanOptions || {};
    if (span.isRecordingEvents()) {
        newOptions = __assign(__assign({}, tracingOptions), { parent: span });
    }
    return {
        span: span,
        spanOptions: newOptions
    };
}
//# sourceMappingURL=tracing.js.map