#include "nfs4_get_ace_access.c"
#include "acl_nfs4_get_who.c"
#include "nfs4_get_ace_type.c"
#include "nfs4_get_ace_flags.c"
#include <node_api.h>
#include <string.h>
#include <stdio.h>
#include <errno.h>
#include <sys/types.h>
#include <libgen.h>
#include "libacl_nfs4.h"
#include "nfs4_acl_utils.c"
#include "nfs4_print_acl.c"
#include "nfs4_new_ace.c"
#include <sys/types.h>
#include <attr/xattr.h>
#include <sys/stat.h>
#include "nfs4_print_ace.c"
#include "acl_nfs4_xattr_load.c"
#include "acl_nfs4_get_whotype.c"
#include "nfs4_free_acl.c"
#include "acl_nfs4_set_who.c"
#include "nfs4_new_acl.c"
#include <stdlib.h>
#include <unistd.h> 
#include <linux/limits.h>

napi_value getAcl(napi_env env, napi_callback_info info) {
    
  char* buffer = NULL;
  size_t bufferSize = 0;
  
  FILE* myStream = open_memstream(&buffer, &bufferSize);  

  char file[PATH_MAX];
  napi_status status;
  size_t argc = 1;
  size_t writtenBytes;
  napi_value argv[1];

  status = napi_get_cb_info(env, info, &argc, argv, NULL, NULL);

  if (status != napi_ok) {
    napi_throw_error(env, NULL, "Failed to parse arguments");
  }

  status = napi_get_value_string_utf8(env, argv[0], file, 1024, &writtenBytes);

  if (status != napi_ok) {
    napi_throw_error(env, NULL, "Invalid string was passed as argument");
  }
  
  struct nfs4_acl *acl; 
  acl =  nfs4_acl_for_path(file);
        if (acl != NULL) {
               nfs4_print_acl(myStream, acl);
        }
        else {
		    char errorMsg[1052] = "Could not get acl of path: ";
    	   	napi_throw_error(env, NULL, strcat(errorMsg, file));
 	}
  nfs4_free_acl(acl); 
  fclose(myStream);
  
  napi_value myString;
  
  status = napi_create_string_utf8(env, buffer, NAPI_AUTO_LENGTH, &myString);
  free(buffer);
  if (status != napi_ok) {
    napi_throw_error(env, NULL, "Unable to create return value");
  }
  return myString;
}

static int nfs4_getxattr(const char *, void *, size_t);

/* returns a newly-allocated struct nfs4_acl for `path', or NULL on error. */
struct nfs4_acl* nfs4_acl_for_path(const char *path)
{
       
        int result;
        struct nfs4_acl *acl = NULL;
        struct stat st;
        char *xattr;
        u32 iflags;

        if (path == NULL)
                goto out;

        result = stat(path, &st);
        if (result < 0) {
                printf("Invalid filename: %s\n", path);
                goto out;
        }
        if (st.st_mode & S_IFDIR)
                iflags = NFS4_ACL_ISDIR;
        else
                iflags = NFS4_ACL_ISFILE;

        /* find necessary buffer size */
        result = nfs4_getxattr(path, NULL, 0);
        if (result < 0)
                goto out;
        xattr = malloc(result);
        if (!xattr) {
                printf("Failed to allocate memory\n");
                goto out;
        }

        /* reconstruct the ACL */
        result = nfs4_getxattr(path, xattr, result);
        if (result < 0)
                goto out_free;     
	acl = acl_nfs4_xattr_load(xattr, result, iflags);
        if (acl == NULL)
                perror("Failed to extract nfs4acl from xattr");
out_free:
        free(xattr);
out:
        return acl;
}

static int nfs4_getxattr(const char *path, void *value, size_t size)
{
        int res;

        res = getxattr(path, ACL_NFS4_XATTR, value, size);
        if (res < -10000) {
                fprintf(stderr,"An internal NFS server error code (%d) was returned; this should never happen.\n",res);
        } else if (res < 0) {
                if (errno == ENOATTR)
                        fprintf(stderr,"Attribute not found on file.\n");
                else if (errno == EREMOTEIO)
                    fprintf(stderr,"An NFS server error occurred.\n");
                else if (errno == EOPNOTSUPP)
                        fprintf(stderr,"Operation to request attribute not supported.\n");
                else
                        perror("Failed getxattr operation");
        }
        return res;
} 

napi_value Init(napi_env env, napi_value exports) {
  napi_status status;
  napi_value fn;

  status = napi_create_function(env, NULL, 0, getAcl, NULL, &fn);
  if (status != napi_ok) {
    napi_throw_error(env, NULL, "Unable to wrap native function");
  }

  status = napi_set_named_property(env, exports, "get", fn);
  if (status != napi_ok) {
    napi_throw_error(env, NULL, "Unable to populate exports");
  }

  return exports;
}


NAPI_MODULE(NODE_GYP_MODULE_NAME, Init)
